-- Index Usage Stats Demo
-- Blog post: http://blogs.msdn.com/sqlserverstorageengine/archive/2007/04/20/how-can-you-tell-if-an-index-is-being-used.aspx
-- Rangers April 2007

-- Look at index usage stats
SELECT * FROM sys.dm_db_index_usage_stats;
GO

-- Now use filter on the DMV
SELECT * FROM sys.dm_db_index_usage_stats
WHERE database_id = DB_ID('AdventureWorks')
and object_id = OBJECT_ID('AdventureWorks.Person.Address');
GO

-- Do something to use the table
SELECT *
FROM AdventureWorks.Person.Address;
GO

-- Do something to use a non-clustered index
SELECT StateProvinceID
FROM AdventureWorks.Person.Address
WHERE StateProvinceID > 4
AND StateProvinceId < 15;
GO

-- Create a table to hold the periodic snapshots of index usage stats
IF OBJECTPROPERTY(object_id(N'master.dbo.MyIndexUsageStats'), 'IsUserTable') = 1
	DROP TABLE dbo.MyIndexUsageStats;
GO

SELECT GETDATE () AS ExecutionTime, *
INTO master.dbo.MyIndexUsageStats
FROM sys.dm_db_index_usage_stats WHERE database_id=0;
GO

-- Take a baseline snapshot of the index usage stats DMV
INSERT master.dbo.MyIndexUsageStats 
	SELECT getdate (), * 
FROM sys.dm_db_index_usage_stats;
GO

-- Do a bunch of stuff
SELECT * FROM AdventureWorks.Person.Address;
GO
SELECT * FROM AdventureWorks.Person.Address;
GO
SELECT StateProvinceID
FROM AdventureWorks.Person.Address
WHERE StateProvinceID > 4
AND StateProvinceId < 15;
GO

-- Take another snapshot
INSERT master.dbo.MyIndexUsageStats 
	SELECT getdate (), * 
FROM sys.dm_db_index_usage_stats;
GO

-- Look at the history of usage
SELECT * FROM master.dbo.MyIndexUsageStats
WHERE database_id = DB_ID('AdventureWorks')
and object_id = OBJECT_ID('AdventureWorks.Person.Address');
GO
